/*
 * Licensed Materials - Property of IBM
 * 
 * 		5724-I66
 * 
 * (C) Copyright IBM Corporation 2005. All Rights Reserved. 
 * 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 * 
 * DISCLAIMER:
 * The following [enclosed] code is sample code created by IBM
 * Corporation. This sample code is not part of any standard IBM product
 * and is provided to you solely for the purpose of assisting you in the
 * development of your applications. The code is provided 'AS IS',
 * without warranty of any kind IBM shall not be liable for any damages
 * arising out of your use of sample code, even if they have been
 * advised of the possibility of such damages.
 */ 

package com.emerged.brokerage;


import java.util.List;
import java.util.Vector;

import commonj.sdo.DataObject;



import com.ibm.websphere.sca.ServiceManager;

public class BrokerageImpl {
	
	private com.ibm.websphere.sca.ServiceManager serviceManager = null;		
	private com.ibm.websphere.bo.BOFactory boFactory = null;
	private static BrokerageBean bean = null;
	
	/**
	 * Default constructor.
	 */
	public BrokerageImpl() {
		super();
		initialize();
	}

	private void initialize() {
		try{
			//get the service manager
			serviceManager = new com.ibm.websphere.sca.ServiceManager();
			//get the BO factory
			boFactory = (com.ibm.websphere.bo.BOFactory)serviceManager.locateService("com/ibm/websphere/bo/BOFactory");
			
			//initialize the brokerage application bean
			bean = new BrokerageBean();
		}
		catch(Exception e){
			e.printStackTrace();
		}
	}
	
	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This should be used when passing this service to another reference api
	 * or if you want to invoke yourself asynchonously.
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	private Object getMyService() {
		return (Object) ServiceManager.INSTANCE.locateService("self");
	}

	
	private Customer convertSDOCustomer(DataObject sdoCustomer){
		Customer c = null;

		if (sdoCustomer != null) {
			
			
			try {
	
				//get all the data from the SDO customer object
				String customerNumber     = sdoCustomer.getString("customerNumber");
				String customerSince = sdoCustomer.getString("customerSince");
				String firstName = sdoCustomer.getString("firstName");
				String lastName = sdoCustomer.getString("lastName");
				
				DataObject sdoAddress = sdoCustomer.getDataObject("address");
				
				String phoneNumber = sdoCustomer.getString("phoneNumber");
				String sin = sdoCustomer.getString("sin");
				double cashBalance = sdoCustomer.getDouble("cashBalance");
				double maximumTransactionAmount = sdoCustomer.getDouble("maximumTransactionAmount");
				int returnCode = sdoCustomer.getInt("returnCode");
				int numberOfStockSymbols = sdoCustomer.getInt("numberOfStockSymbols");
				List quantityOfShares = sdoCustomer.getList("quantityOfShares");
				List stockSymbols = sdoCustomer.getList("stockSymbols");
				
				DataObject sdoOldData = sdoCustomer.getDataObject("oldData");				
	
				//create a Customer object and set its data
				c = new Customer();			
				c.setCustomerNumber(customerNumber);
				c.setCustomerSince(customerSince);
				c.setFirstName(firstName);
				c.setLastName(lastName);
				c.setAddress( convertSDOAddress(sdoAddress) );
				c.setPhoneNumber(phoneNumber);
				c.setSin(sin);
				c.setCashBalance( new Double(cashBalance) );
				c.setMaximumTransactionAmount( new Double(maximumTransactionAmount) );
				c.setReturnCode( new Integer(returnCode) );
				c.setNumberOfStockSymbols( new Integer(numberOfStockSymbols) );
				c.setQuantityOfShares( convertSDOQuantityOfShares(quantityOfShares) );
				c.setStockSymbols( convertSDOStockSymbols(stockSymbols) );
				c.setOldData(convertSDOOldCustomer(sdoOldData));
				
			}
			catch(Exception e){
				e.printStackTrace();
				c = null;
			}
		}
		
		return c;
	}
	
	private Address convertSDOAddress(DataObject sdoAddress) {
		Address a = null;
		
		if (sdoAddress != null){
			try{
				
				//get all the data from the SDO address object				
				String street = sdoAddress.getString("street");
				String city = sdoAddress.getString("city");
				String state = sdoAddress.getString("state");
				String country = sdoAddress.getString("country");
				String zipCode = sdoAddress.getString("zipCode");

				//create an Address object and set its data
				a = new Address();
				a.setStreet(street);
				a.setCity(city);
				a.setState(state);
				a.setCountry(country);
				a.setZipCode(zipCode);
				
			}
			catch(Exception e){
				e.printStackTrace();
				a=null;
			}
		}
		
		
		return a;
	}
	private OldCustomer convertSDOOldCustomer(DataObject sdoOldCustomer) {
		OldCustomer c = null;
		
		if (sdoOldCustomer != null){
		   try {
		   	
			    //get all the data from the SDO oldcustomer object		   	
				String customerNumber     = sdoOldCustomer.getString("customerNumber");
				String customerSince = sdoOldCustomer.getString("customerSince");
				String firstName = sdoOldCustomer.getString("firstName");
				String lastName = sdoOldCustomer.getString("lastName");
				
				DataObject sdoAddress = sdoOldCustomer.getDataObject("address");
				
				String phoneNumber = sdoOldCustomer.getString("phoneNumber");
				String sin = sdoOldCustomer.getString("sin");
				double cashBalance = sdoOldCustomer.getDouble("cashBalance");
				double maximumTransactionAmount = sdoOldCustomer.getDouble("maximumTransactionAmount");
	
				int numberOfStockSymbols = sdoOldCustomer.getInt("numberOfStockSymbols");
				List quantityOfShares = sdoOldCustomer.getList("quantityOfShares");
				List stockSymbols = sdoOldCustomer.getList("stockSymbols");
				
				//create an OldCustomer object and set its data
				c = new OldCustomer();
				c.setCustomerNumber(customerNumber);
				c.setCustomerSince(customerSince);
				c.setFirstName(firstName);
				c.setLastName(lastName);
				c.setAddress( convertSDOAddress(sdoAddress) );
				c.setPhoneNumber(phoneNumber);
				c.setSin(sin);
				c.setCashBalance( new Double(cashBalance) );
				c.setMaximumTransactionAmount( new Double(maximumTransactionAmount) );
			   	c.setNumberOfStockSymbols( new Integer(numberOfStockSymbols) );
			   	c.setQuantityOfShares( convertSDOQuantityOfShares(quantityOfShares) );
			   	c.setStockSymbols( convertSDOStockSymbols(stockSymbols) );
		   	
		   }
		   catch(Exception e){
		   	 e.printStackTrace();
		   	 c = null;
		   }
		}
		
		return c;
	}
	
	private Integer[] convertSDOQuantityOfShares(List qtyOfSharesList) {
		Integer[] qtyOfShares = null;
		
		//convert a List of Integers into an array of integers
		if (qtyOfSharesList != null){
			try {
				qtyOfShares = (Integer[])qtyOfSharesList.toArray(new Integer[0]);
			}
			catch(Exception e){
				e.printStackTrace();
				qtyOfShares = null;
			}
		}
		
		return qtyOfShares;
	}
	private String[] convertSDOStockSymbols(List stockSymbolsList) {
		String[] stockSymbols = null;
		
		if (stockSymbolsList != null){
			try {
				stockSymbols = (String[])stockSymbolsList.toArray(new String[0]);
			}
			catch(Exception e){
				e.printStackTrace();
				stockSymbols = null;
			}
		}
		
		return stockSymbols;
	}
	
	/**
	 * Method generated to support implemention of operation "createCustomer" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject createCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			
			//call the bank application
			Customer oc = bean.createCustomer(ic);

			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;
	}

	private DataObject convertToSDOCustomer(Customer c){
		DataObject sdoCustomer = null;
		Double value = null;
		Integer iValue = null;
		
		if (c != null){
			
			try {
				
				
				//create the Customer sdo data object and set its properties
				sdoCustomer = boFactory.create("http://BrokerageModule/com/emerged/brokerage", "CustomerBO");
				
				sdoCustomer.setString("customerNumber",c.getCustomerNumber());
				sdoCustomer.setString("customerSince",c.getCustomerSince());
				sdoCustomer.setString("firstName",c.getFirstName());
				sdoCustomer.setString("lastName",c.getLastName());				
				
				sdoCustomer.setDataObject("address", convertToSDOAddress( c.getAddress() ) );
				
				sdoCustomer.setString("phoneNumber",c.getPhoneNumber());				
				sdoCustomer.setString("sin",c.getSin());
				
				value = c.getCashBalance();
				if (value != null){
				    sdoCustomer.setDouble("cashBalance", value.doubleValue() );
				}
				
				value = c.getMaximumTransactionAmount();
				if (value != null){
				   sdoCustomer.setDouble("maximumTransactionAmount",value.doubleValue());
				}
				
				iValue = c.getReturnCode();
				if (iValue != null){
			 	    sdoCustomer.setInt("returnCode",iValue.intValue());
				}
				
				iValue = c.getNumberOfStockSymbols();			
				if (iValue != null) {
				   sdoCustomer.setInt("numberOfStockSymbols",iValue.intValue());
				}
				
				sdoCustomer.setList("quantityOfShares",convertToList( c.getQuantityOfShares() ));		
				sdoCustomer.setList("stockSymbols",convertToList( c.getStockSymbols() ));
				sdoCustomer.setDataObject("oldData", convertToSDOOldCustomer(c.getOldData()) );
				
				
			}
			catch(Exception e){
		          e.printStackTrace();
		          sdoCustomer = null;
			}
			
		}
		
		return sdoCustomer;
	}
	
	private DataObject convertToSDOOldCustomer(OldCustomer c){
		DataObject sdoCustomer = null;
		Double value = null;
		Integer iValue = null;
		
		if (c != null){
			
			try {
				
				//create the Customer sdo data object and set its properties
				sdoCustomer = boFactory.create("http://BrokerageModule/com/emerged/brokerage", "OldCustomerBO");
				
				sdoCustomer.setString("customerNumber",c.getCustomerNumber());
				sdoCustomer.setString("customerSince",c.getCustomerSince());
				sdoCustomer.setString("firstName",c.getFirstName());
				sdoCustomer.setString("lastName",c.getLastName());				
				
				sdoCustomer.setDataObject("address", convertToSDOAddress(c.getAddress()) );
				
				sdoCustomer.setString("phoneNumber",c.getPhoneNumber());				
				sdoCustomer.setString("sin",c.getSin());
				
				value = c.getCashBalance();
				if (value != null) {
				    sdoCustomer.setDouble("cashBalance", value.doubleValue() );
				}
				
				value = c.getMaximumTransactionAmount();
				if (value != null){
				    sdoCustomer.setDouble("maximumTransactionAmount",value.doubleValue());
				}
				
				iValue = c.getNumberOfStockSymbols();
				if (iValue != null) {
				   sdoCustomer.setInt("numberOfStockSymbols",iValue.intValue());
				}
				
				sdoCustomer.setList("quantityOfShares",convertToList( c.getQuantityOfShares() ));		
				sdoCustomer.setList("stockSymbols",convertToList( c.getStockSymbols() ));
				
			}
			catch(Exception e){
		          e.printStackTrace();
		          sdoCustomer = null;
			}
			
		}
		
		return sdoCustomer;
	}
	
	private DataObject convertToSDOAddress(Address a){
		
	   DataObject sdoAddress = null;

	   if (a != null){
	   	   try {
	   	   	
               //create the Address sdo data object and set its properties
	   	       sdoAddress = boFactory.create("http://BrokerageModule/com/emerged/brokerage", "AddressBO");
	   	       
	   	       sdoAddress.setString("street",a.getStreet());
	   	       sdoAddress.setString("city",a.getCity());
	   	       sdoAddress.setString("state",a.getState());
	   	       sdoAddress.setString("country",a.getCountry());
	   	       sdoAddress.setString("zipCode",a.getZipCode());	   	       

	   	   }
	   	   catch(Exception e){
	   	   	   e.printStackTrace();
	   	   	   a = null;
	   	   }
	   }
	   
	   return sdoAddress;
	}

	private List convertToList(Object[] objects){
		List list = null;
		list = new Vector();
		
		if(objects !=null){
			try {

				for (int i = 0; i < objects.length; i++) {
					list.add(objects[i]);
				}
			}
			catch(Exception e){
				e.printStackTrace();
				list = null;
			}
		}
		return list;
	}

	private SharesRequest convertSDOSharesRequest(DataObject sdoSharesRequest) {
		SharesRequest sr = null;
		
		if (sdoSharesRequest!=null){
			try {
				
				String customerNumber               = sdoSharesRequest.getString("customerNumber");
				String stockSymbol                  = sdoSharesRequest.getString("stockSymbol");
				int    quantityOfShares             = sdoSharesRequest.getInt("quantityOfShares");
				double pricePerShare                = sdoSharesRequest.getDouble("pricePerShare");
				double commission                   = sdoSharesRequest.getDouble("commission");
				int    returnCode                   = sdoSharesRequest.getInt("returnCode");
				int    updatedTotalQuantityOfShares = sdoSharesRequest.getInt("updatedTotalQuantityOfShares");
				double cashAmount                   = sdoSharesRequest.getDouble("cashAmount");

				
				sr = new SharesRequest();
				sr.setCustomerNumber(customerNumber);
				sr.setStockSymbol(stockSymbol);
				sr.setQuantityOfShares( new Integer(quantityOfShares) );
				sr.setPricePerShare( new Double(pricePerShare) );
				sr.setCommission( new Double(commission) );
				sr.setReturnCode( new Integer(returnCode) );
				sr.setUpdatedTotalQuantityOfShares( new Integer(updatedTotalQuantityOfShares) );
				sr.setCashAmount( new Double(cashAmount) );
				
			}
			catch(Exception e){
				e.printStackTrace();
				sr = null;
			}
		}
		
		return sr;
	}

	private DataObject convertToSDOSharesRequest(SharesRequest sharesRequest) {
		DataObject sdoSharesRequest = null;
		
		if (sharesRequest!=null){
			try {
				
				//create the sharesrequest sdo data object and set its properties
				sdoSharesRequest = boFactory.create("http://BrokerageModule/com/emerged/brokerage", "SharesRequestBO");
				
				sdoSharesRequest.setString("customerNumber",sharesRequest.getCustomerNumber());
				sdoSharesRequest.setString("stockSymbol",sharesRequest.getStockSymbol());				
				sdoSharesRequest.setInt("quantityOfShares",sharesRequest.getQuantityOfShares().intValue());
				sdoSharesRequest.setDouble("pricePerShare",sharesRequest.getPricePerShare().doubleValue());				
				sdoSharesRequest.setDouble("commission",sharesRequest.getCommission().doubleValue());
				sdoSharesRequest.setInt("returnCode",sharesRequest.getReturnCode().intValue());				
				sdoSharesRequest.setInt("updatedTotalQuantityOfShares",sharesRequest.getUpdatedTotalQuantityOfShares().intValue());
				sdoSharesRequest.setDouble("cashAmount",sharesRequest.getCashAmount().doubleValue());				
				
			}
			catch(Exception e){
				e.printStackTrace();
				sdoSharesRequest = null;
			}
		}
		
		return sdoSharesRequest;
	}
	
	private CashBalanceChangeRequest convertSDOCashBalanceChangeRequest(DataObject sdoCashBalanceChangeRequest) {
		CashBalanceChangeRequest cbcr = null;
		
		if (sdoCashBalanceChangeRequest!=null){
			try {

				String customerNumber = sdoCashBalanceChangeRequest.getString("customerNumber");
				double amount         = sdoCashBalanceChangeRequest.getDouble("amount");
				int returnCode        = sdoCashBalanceChangeRequest.getInt("returnCode");
				double updatedBalance = sdoCashBalanceChangeRequest.getDouble("updatedBalance");				
				
				cbcr = new CashBalanceChangeRequest();
				cbcr.setCustomerNumber(customerNumber);
				cbcr.setAmount(new Double(amount));
				cbcr.setReturnCode(new Integer(returnCode));
				cbcr.setUpdatedBalance(new Double(updatedBalance));
				
			}
			catch(Exception e){
				e.printStackTrace();
				cbcr = null;
			}
		}
		
		return cbcr;
	}
	private DataObject convertToSDOCashBalanceChangeRequest(CashBalanceChangeRequest cashBalanceChangeRequest) {
		DataObject sdoCashBalanceChangeRequest = null;
		
		if (cashBalanceChangeRequest!=null){
			try {
				
				//create the cashbalancechangerequest sdo data object and set its properties
				sdoCashBalanceChangeRequest = boFactory.create("http://BrokerageModule/com/emerged/brokerage", "CashBalanceChangeRequestBO");
				
				sdoCashBalanceChangeRequest.setString("customerNumber",cashBalanceChangeRequest.getCustomerNumber());
				sdoCashBalanceChangeRequest.setDouble("amount",cashBalanceChangeRequest.getAmount().doubleValue());
				sdoCashBalanceChangeRequest.setInt("returnCode",cashBalanceChangeRequest.getReturnCode().intValue());
				sdoCashBalanceChangeRequest.setDouble("updatedBalance",cashBalanceChangeRequest.getUpdatedBalance().doubleValue());
				
				
			}
			catch(Exception e){
				e.printStackTrace();
				sdoCashBalanceChangeRequest = null;
			}
		}
		
		return sdoCashBalanceChangeRequest;
	}

	private WebLoginInfo convertSDOWebLoginInfo(DataObject sdoWebLoginInfo) {
		WebLoginInfo w = null;
		
		if (sdoWebLoginInfo!=null){
			try {

				String customerNumber = sdoWebLoginInfo.getString("customerNumber");
				String password       = sdoWebLoginInfo.getString("password");
				int    returnCode     = sdoWebLoginInfo.getInt("returnCode");
				
				w = new WebLoginInfo();
				w.setCustomerNumber(customerNumber);
				w.setPassword(password);
				w.setReturnCode( new Integer(returnCode) );
				
			}
			catch(Exception e){
				e.printStackTrace();
				w = null;
			}
		}
		
		return w;
	}
	private DataObject convertToSDOWebLoginInfo(WebLoginInfo webLoginInfo) {
		DataObject sdoWebLoginInfo = null;
		
		if (webLoginInfo!=null){
			try {
				
				//create the weblogininfo sdo data object and set its properties
				sdoWebLoginInfo = boFactory.create("http://BrokerageModule/com/emerged/brokerage", "WebLoginInfoBO");
				
				sdoWebLoginInfo.setString("customerNumber",webLoginInfo.getCustomerNumber());
				sdoWebLoginInfo.setString("password",webLoginInfo.getPassword());
				sdoWebLoginInfo.setInt("returnCode",webLoginInfo.getReturnCode().intValue());				
				
			}
			catch(Exception e){
				e.printStackTrace();
				sdoWebLoginInfo = null;
			}
		}
		
		return sdoWebLoginInfo;
	}
	
	/**
	 * Method generated to support implemention of operation "retrieveCustomer" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject retrieveCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			
			//call the bank application
			Customer oc = bean.retrieveCustomer(ic);

			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;
	}

	/**
	 * Method generated to support implemention of operation "updateCustomer" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject updateCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			
			//call the bank application
			Customer oc = bean.updateCustomer(ic);

			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;
	}

	/**
	 * Method generated to support implemention of operation "deleteCustomer" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject deleteCustomer(DataObject inputCustomer) {
		DataObject outputCustomer = null;
		
		try {
		
			//convert sdo customer object into a Customer object
			Customer ic = convertSDOCustomer(inputCustomer);
			
			
			//call the bank application
			Customer oc = bean.deleteCustomer(ic);

			
			//convert the Customer object into an sdo customer object
			outputCustomer = convertToSDOCustomer(oc);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCustomer;

	}

	/**
	 * Method generated to support implemention of operation "buyShares" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject buyShares(DataObject inputSharesRequest) {
		DataObject outputSharesRequest = null;
		
		try {
		
			//convert sdo sharesrequest object into a SharesRequest object
			SharesRequest isr = convertSDOSharesRequest(inputSharesRequest);
			
			
			//call the bank application
			SharesRequest osr = bean.buyShares(isr);

			
			//convert the SharesRequest object into an sdo sharesrequest object
			outputSharesRequest = convertToSDOSharesRequest(osr);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputSharesRequest;


	}

	/**
	 * Method generated to support implemention of operation "sellShares" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject sellShares(DataObject inputSharesRequest) {
		DataObject outputSharesRequest = null;
		
		try {
		
			//convert sdo sharesrequest object into a SharesRequest object
			SharesRequest isr = convertSDOSharesRequest(inputSharesRequest);
			
			
			//call the bank application
			SharesRequest osr = bean.sellShares(isr);

			
			//convert the SharesRequest object into an sdo sharesrequest object
			outputSharesRequest = convertToSDOSharesRequest(osr);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputSharesRequest;
	}

	/**
	 * Method generated to support implemention of operation "deposit" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject deposit(DataObject inputCashBalanceChangeRequest) {
		DataObject outputCashBalanceChangeRequest = null;
		
		try {
		
			//convert sdo cashbalancechangerequest object into a CashBalanceChangeRequest object
			CashBalanceChangeRequest icbcr = convertSDOCashBalanceChangeRequest(inputCashBalanceChangeRequest);
			
			
			//call the bank application
			CashBalanceChangeRequest ocbcr = bean.deposit(icbcr);

			
			//convert the CashBalanceChangeRequest object into an sdo cashbalancechangerequest object
			outputCashBalanceChangeRequest = convertToSDOCashBalanceChangeRequest(ocbcr);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCashBalanceChangeRequest;
	}

	/**
	 * Method generated to support implemention of operation "withdraw" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject withdraw(DataObject inputCashBalanceChangeRequest) {
		DataObject outputCashBalanceChangeRequest = null;
		
		try {
		
			//convert sdo cashbalancechangerequest object into a CashBalanceChangeRequest object
			CashBalanceChangeRequest icbcr = convertSDOCashBalanceChangeRequest(inputCashBalanceChangeRequest);
			
			
			//call the bank application
			CashBalanceChangeRequest ocbcr = bean.withdraw(icbcr);

			
			//convert the CashBalanceChangeRequest object into an sdo cashbalancechangerequest object
			outputCashBalanceChangeRequest = convertToSDOCashBalanceChangeRequest(ocbcr);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputCashBalanceChangeRequest;
	}

	/**
	 * Method generated to support implemention of operation "validateWebUser" defined for WSDL port type 
	 * named "interface.Brokerage".
	 * 
	 * The presence of commonj.sdo.DataObject as the return type and/or as a parameter 
	 * type conveys that its a complex type. Please refer to the WSDL Definition for more information 
	 * on the type of input, output and fault(s).
	 */
	public DataObject validateWebUser(DataObject inputWebLoginInfo) {
		DataObject outputWebLoginInfo = null;
		
		try {
		
			//convert sdo weblogininfo object into a WebLoginInfo object
			WebLoginInfo iw = convertSDOWebLoginInfo(inputWebLoginInfo);
			
			
			//call the bank application
			WebLoginInfo ow = bean.validateWebUser(iw);

			
			//convert the WebLoginInfo object into an sdo weblogininfo object
			outputWebLoginInfo = convertToSDOWebLoginInfo(ow);
			
		}
		catch(Exception e){
           e.printStackTrace();			
		}
		
		return outputWebLoginInfo;

	}

}